@@ -1,7 +1,7 @@
 /*******************************************************************
 
 Part of the Fritzing project - http://fritzing.org
-Copyright (c) 2007-2012 Fachhochschule Potsdam - http://fh-potsdam.de
+Copyright (c) 2007-2019 Fritzing
 
 Fritzing is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -16,12 +16,6 @@ GNU General Public License for more details.
 You should have received a copy of the GNU General Public License
 along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.
 
-********************************************************************
-
-$Revision: 6904 $:
-$Author: irascibl@gmail.com $:
-$Date: 2013-02-26 16:26:03 +0100 (Di, 26. Feb 2013) $
-
 ********************************************************************/
 
 #ifndef SEARCHLINEEDIT_H
@@ -31,24 +25,24 @@ $Date: 2013-02-26 16:26:03 +0100 (Di, 26. Feb 2013) $
 #include <QMouseEvent>
 
 class SearchLineEdit : public QLineEdit {
-Q_OBJECT
+	Q_OBJECT
 
 public:
-	SearchLineEdit(QWidget * parent = NULL);
-	~SearchLineEdit();
+	SearchLineEdit(QWidget * parent = nullptr);
+	~SearchLineEdit() = default;
 
-	void setDecoy(bool);
-	bool decoy();
+	void setDecoy(bool value);
+	constexpr bool decoy() const noexcept { return m_decoy; }
 
 public:
 	static void cleanup();
 
 signals:
-    void clicked();
+	void clicked();
 
 protected:
 	void paintEvent(QPaintEvent *);
-    void mousePressEvent(QMouseEvent *);
+	void mousePressEvent(QMouseEvent *);
 	void enterEvent( QEvent *);
 	void leaveEvent( QEvent *);
 	void setColors(const QColor & base, const QColor & text);
